Mesa (master): gitlab-ci: Install WINE from Debian testing

GitLab Mirror gitlab-mirror at kemper.freedesktop.org
Thu May 14 13:12:06 UTC 2020


Module: Mesa
Branch: master
Commit: da3aee926387cb9113b79c5376a6a8f4295582ac
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=da3aee926387cb9113b79c5376a6a8f4295582ac

Author: Michel Dänzer <mdaenzer at redhat.com>
Date:   Mon Apr 27 12:42:58 2020 +0200

gitlab-ci: Install WINE from Debian testing

Instead of a third-party repository which has proved unreliable at
times.

This pulls in glibc 2.30 from testing in the x86_build image, so we need
to update the x86_test-{gl,vk} images to match.

Acked-by: Andres Gomez <agomez at igalia.com>
Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/4851>

---

 .gitlab-ci.yml                                     |  6 ++---
 .../container/obs-emulators-wine-debian.gpg.key    | 20 ---------------
 .gitlab-ci/container/x86_build.sh                  | 30 +++++++++++-----------
 .gitlab-ci/container/x86_test-gl.sh                | 13 +++++++---
 .gitlab-ci/container/x86_test-vk.sh                | 14 +++++++++-
 5 files changed, 40 insertions(+), 43 deletions(-)

diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index b2196cee5e9..0fb1b5cf8a9 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -146,13 +146,13 @@ x86_build:
 x86_test-gl:
   extends: x86_build
   variables:
-    FDO_DISTRIBUTION_TAG: &x86_test-gl "2020-04-21"
+    FDO_DISTRIBUTION_TAG: &x86_test-gl "2020-05-08"
 
 # Debian 10 based x86 test image for VK
 x86_test-vk:
   extends: x86_build
   variables:
-    FDO_DISTRIBUTION_TAG: &x86_test-vk "2020-04-09"
+    FDO_DISTRIBUTION_TAG: &x86_test-vk "2020-05-08"
 
 # Debian 9 based x86 build image (old LLVM)
 x86_build_old:
@@ -549,7 +549,7 @@ meson-s390x:
   script:
     # For unknown reasons "too many" installed i386 libraries cause qemu to
     # crash while executing llvm-config for s390x.
-    - apt-get purge -y winehq-stable
+    - apt-get purge -y wine32
     - apt-get autoremove -y --purge
     - dpkg -i /var/cache/apt/archives/$CROSS/*.deb
     - .gitlab-ci/meson-build.sh
diff --git a/.gitlab-ci/container/obs-emulators-wine-debian.gpg.key b/.gitlab-ci/container/obs-emulators-wine-debian.gpg.key
deleted file mode 100644
index df8a06ba48e..00000000000
--- a/.gitlab-ci/container/obs-emulators-wine-debian.gpg.key
+++ /dev/null
@@ -1,20 +0,0 @@
------BEGIN PGP PUBLIC KEY BLOCK-----
-Version: GnuPG v2.0.15 (GNU/Linux)
-
-mQENBFu8fWQBCADM64J7qlcnI2KwxSKSdyaOi7hz44EUXDpC3+3hfFP8k28SgV3U
-4a/ydOdd2cDSne5w+yjrnJWYuS0sTiE7vQPtKfmCmQZfCStvoRe5Pt+AOy1GA/iu
-U5wHIZD+/A9CeQcu5L3PkVkmijz0LmSCq7HnnVB0SdFA5eFlV98H875EasvpJ3xU
-ziI3yvqdZ5/0LgKzOiFjk4rMXQS01a1dNpwFO7EXiq921ZjnXatdnsDQ/NAj7z8P
-3qnTAj6yvl7DtdlXXA2hiznEOZNCRLZ69vHq0hGIw+OKjpsUkCZK29AnY4wJxxzY
-frjknVW7tyZ6Hxwz6R4vaVlZ6h5WR/OiAdqlABEBAAG0NEVtdWxhdG9ycyBPQlMg
-UHJvamVjdCA8RW11bGF0b3JzQGJ1aWxkLm9wZW5zdXNlLm9yZz6JAT4EEwEIACgF
-Alu8fWQCGwMFCQQesAAGCwkIBwMCBhUIAgkKCwQWAgMBAh4BAheAAAoJEN+hdadR
-BJYOXVoH/Rd0dRx4SUx7KVjTrDfSuf6jXseyenkl4aQnp46n0MttatkoCdGVvyrq
-VWvGfO3MI122MnFKqia7Hep1HlcYGe2a5tW/w1SGGEy+VZduxcZCMmVuSnl+3ioG
-2fRGx3uoNBEGQIbZ5VVlABUJC+c/Vq1m6kT9Edz4XWRPHW1Nwjjfn79618ebGZMc
-R0fUM9L3GZw9V/kAK8kXmIL7rkglfewTbs6fByqAix79MjsNURAuCeIc5OmbxL4j
-LxuoNhnxxucB7YGBhCa9ZL8LYEIbdeyaJmgdHDoUQjz4peXibz5v+Er8mGOwuSLl
-y1U21T3huNf9Osjw52nxVcDmugBWqQKIRgQTEQIABgUCW7x9ZAAKCRA7MBG3a51l
-IwayAJ9dHmDag9nFY9GujfMr+foKquFS9wCfQlvp6Sz0N5aKdW00NGnZZ/EKHIQ=
-=uZyA
------END PGP PUBLIC KEY BLOCK-----
diff --git a/.gitlab-ci/container/x86_build.sh b/.gitlab-ci/container/x86_build.sh
index 5980d1550d8..87d1b93b47f 100644
--- a/.gitlab-ci/container/x86_build.sh
+++ b/.gitlab-ci/container/x86_build.sh
@@ -20,19 +20,6 @@ apt-get install -y \
 apt-key add .gitlab-ci/container/llvm-snapshot.gpg.key
 echo "deb https://apt.llvm.org/buster/ llvm-toolchain-buster-9 main" >/etc/apt/sources.list.d/llvm9.list
 
-# Upstream Wine (WineHQ) package repository. We use the OBS service
-# instead of the repository at the winehq.org domain because:
-#
-#   " The WineHQ packages for Debian 10 and later require libfaudio0
-#     as a dependency. Since the distro does not provide it for Debian
-#     10, users of that version can download libfaudio0 packages from
-#     the OBS. See https://forum.winehq.org/viewtopic.php?f=8&t=32192
-#     for details."
-#
-# As explained at https://wiki.winehq.org/Debian
-apt-key add .gitlab-ci/container/obs-emulators-wine-debian.gpg.key
-echo 'deb https://download.opensuse.org/repositories/Emulators:/Wine:/Debian/Debian_10/ ./' >/etc/apt/sources.list.d/obs-emulators-wine-debian.list
-
 sed -i -e 's/http:\/\/deb/https:\/\/deb/g' /etc/apt/sources.list
 echo 'deb https://deb.debian.org/debian buster-backports main' >/etc/apt/sources.list.d/backports.list
 echo 'deb https://deb.debian.org/debian testing main' >/etc/apt/sources.list.d/testing.list
@@ -142,8 +129,21 @@ apt-get install -y --no-remove -t buster-backports \
 # for 64bit windows cross-builds
 apt-get install -y --no-remove \
       libz-mingw-w64-dev \
-      mingw-w64 \
-      winehq-stable
+      mingw-w64
+
+
+# Install packages we need from Debian testing last, to avoid pulling in more
+
+# Need to allow removing libgcc1 for these
+apt-get install -y -t testing \
+      libstdc++6:i386 \
+      libstdc++6:ppc64el \
+      libstdc++6:s390x
+
+apt-get install -y --no-remove -t testing \
+      wine \
+      wine32 \
+      wine64
 
 
 . .gitlab-ci/container/container_pre_build.sh
diff --git a/.gitlab-ci/container/x86_test-vk.sh b/.gitlab-ci/container/x86_test-vk.sh
index c88199b42bf..455506d2972 100644
--- a/.gitlab-ci/container/x86_test-vk.sh
+++ b/.gitlab-ci/container/x86_test-vk.sh
@@ -14,10 +14,17 @@ apt-key add .gitlab-ci/container/llvm-snapshot.gpg.key
 echo "deb https://apt.llvm.org/buster/ llvm-toolchain-buster-9 main" >/etc/apt/sources.list.d/llvm9.list
 
 sed -i -e 's/http:\/\/deb/https:\/\/deb/g' /etc/apt/sources.list
-echo 'deb https://deb.debian.org/debian buster-backports main' >/etc/apt/sources.list.d/backports.list
+echo 'deb https://deb.debian.org/debian testing main' >/etc/apt/sources.list.d/testing.list
 
 apt-get update
 
+# Don't use newer packages from testing by default
+cat >/etc/apt/preferences <<EOF
+Package: *
+Pin: release a=testing
+Pin-Priority: 100
+EOF
+
 apt-get dist-upgrade -y
 
 apt-get install -y --no-remove \
@@ -74,6 +81,11 @@ apt-get install -y --no-remove \
       wine32 \
       wine64
 
+# Install packages we need from Debian testing last, to avoid pulling in more
+apt-get install -y -t testing \
+      libc6-dev
+
+
 ############### Set up Wine env variables
 
 export WINEDEBUG="-all"



More information about the mesa-commit mailing list
diff --git a/.gitlab-ci/container/x86_test-gl.sh b/.gitlab-ci/container/x86_test-gl.sh
index 1114059053a..a8220df0ec4 100644
--- a/.gitlab-ci/container/x86_test-gl.sh
+++ b/.gitlab-ci/container/x86_test-gl.sh
@@ -14,15 +14,15 @@ apt-key add .gitlab-ci/container/llvm-snapshot.gpg.key
 echo "deb https://apt.llvm.org/buster/ llvm-toolchain-buster-9 main" >/etc/apt/sources.list.d/llvm9.list
 
 sed -i -e 's/http:\/\/deb/https:\/\/deb/g' /etc/apt/sources.list
-echo 'deb https://deb.debian.org/debian buster-backports main' >/etc/apt/sources.list.d/backports.list
+echo 'deb https://deb.debian.org/debian testing main' >/etc/apt/sources.list.d/testing.list
 
 apt-get update
 
 # Use newer packages from backports by default
 cat >/etc/apt/preferences <<EOF
 Package: *
-Pin: release a=buster-backports
-Pin-Priority: 500
+Pin: release a=testing
+Pin-Priority: 100
 EOF
 
 apt-get dist-upgrade -y
@@ -78,6 +78,11 @@ apt-get install -y --no-remove \
       xz-utils \
       zlib1g
 
+# Install packages we need from Debian testing last, to avoid pulling in more
+apt-get install -y -t testing \
+      libc6-dev
+
+
 . .gitlab-ci/container/container_pre_build.sh
 
 ############### Build virglrenderer
@@ -14,15 +14,15 @@ apt-key add .gitlab-ci/container/llvm-snapshot.gpg.key
 apt-get update
 
-# Use newer packages from backports by default
+# Don't use newer packages from testing by default
 cat >/etc/apt/preferences <<EOF
 Package: *